==> Guppi-0.33.1.tar.gz: Guppi-0.33.1/plug-ins/scatter/init.c <==
/* $Id: init.c,v 1.3 2000/01/19 19:48:53 trow Exp $ */

/*
 * init.c
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>
 * and Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <config.h>
#include <guppi-plot-plug-in.h>
#include "guppi-scatter-element.h"
#include "guppi-scm-scatter-style.h"
#include "guppi-scm-scatter-state.h"

GuppiPlotPlugInInfo* plot_plug_in(void);

/***************************************************************************/

static GuppiPlotElement*
make_element(void)
{
  return guppi_scatter_element_new();
}

static GuppiPlotPlugInInfo info = {
  GUPPI_PLOT_PLUG_IN_MAGIC_NUMBER,
  N_("Scatter Plot"),
  "scatter",
  GUPPI_MAJOR_VERSION,
  GUPPI_MINOR_VERSION,
  GUPPI_MICRO_VERSION,
  "Copyright (C) 2000 EMC Capital Management, Inc.",
  "Jon Trowbridge",
  make_element,
  NULL
};


GuppiPlotPlugInInfo*
plot_plug_in(void)
{
  guppi_scm_scatter_style_init();
  guppi_scm_scatter_state_init();

  /* Do any other necessary initialization here. */
  
  return &info;
}


/* $Id: init.c,v 1.3 2000/01/19 19:48:53 trow Exp $ */

==> Guppi-0.34.2.tar.gz: Guppi-0.34.2/plug-ins/scatter/init.c <==
/* $Id: init.c,v 1.5 2000/02/11 19:45:28 trow Exp $ */

/*
 * init.c
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>
 * and Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <config.h>
#include <guppi-plot-plug-in.h>
#include "guppi-scatter-element.h"
#include "guppi-scm-scatter.h"

GuppiPlugIn* guppi_plug_in(void);

/***************************************************************************/

static GuppiPlotElement*
make_element(void)
{
  return guppi_scatter_element_new();
}

GuppiPlugIn*
guppi_plug_in(void)
{
  GuppiPlugIn* pi;
  GuppiPlotPlugIn* ppi;

  pi = guppi_plot_plug_in_new();
  ppi = GUPPI_PLOT_PLUG_IN(pi);

  pi->magic_number = GUPPI_PLUG_IN_MAGIC_NUMBER;
  pi->type = "plot";
  pi->external_name = _("Scatter Plot");
  pi->internal_name = "scatter";
  pi->major_version = GUPPI_MAJOR_VERSION;
  pi->minor_version = GUPPI_MINOR_VERSION;
  pi->micro_version = GUPPI_MICRO_VERSION;
  pi->copyright = "(C) 2000 EMC Capital Management, Inc.";
  pi->authors = "Jon Trowbridge <trow@gnu.org>";

  ppi->element_constructor = make_element;

  guppi_scm_scatter_init();

  /* Do any other necessary initialization here. */
  
  return pi;
}


/* $Id: init.c,v 1.5 2000/02/11 19:45:28 trow Exp $ */
